==> huaweicloudsdkcdn-3.0.49-py2.py3-none-any.whl: huaweicloudsdkcdn/v1/model/list_domains_response.py <==
# coding: utf-8

import pprint
import re

import six


from huaweicloudsdkcore.sdk_response import SdkResponse


class ListDomainsResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'total': 'int',
        'domains': 'list[Domains]'
    }

    attribute_map = {
        'total': 'total',
        'domains': 'domains'
    }

    def __init__(self, total=None, domains=None):
        """ListDomainsResponse - a model defined in huaweicloud sdk"""
        
        super(ListDomainsResponse, self).__init__()

        self._total = None
        self._domains = None
        self.discriminator = None

        if total is not None:
            self.total = total
        if domains is not None:
            self.domains = domains

    @property
    def total(self):
        """Gets the total of this ListDomainsResponse.

        总条数。

        :return: The total of this ListDomainsResponse.
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this ListDomainsResponse.

        总条数。

        :param total: The total of this ListDomainsResponse.
        :type: int
        """
        self._total = total

    @property
    def domains(self):
        """Gets the domains of this ListDomainsResponse.

        域名信息

        :return: The domains of this ListDomainsResponse.
        :rtype: list[Domains]
        """
        return self._domains

    @domains.setter
    def domains(self, domains):
        """Sets the domains of this ListDomainsResponse.

        域名信息

        :param domains: The domains of this ListDomainsResponse.
        :type: list[Domains]
        """
        self._domains = domains

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListDomainsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcdn-3.0.52-py2.py3-none-any.whl: huaweicloudsdkcdn/v1/model/list_domains_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse


class ListDomainsResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'total': 'int',
        'domains': 'list[Domains]'
    }

    attribute_map = {
        'total': 'total',
        'domains': 'domains'
    }

    def __init__(self, total=None, domains=None):
        """ListDomainsResponse - a model defined in huaweicloud sdk"""
        
        super(ListDomainsResponse, self).__init__()

        self._total = None
        self._domains = None
        self.discriminator = None

        if total is not None:
            self.total = total
        if domains is not None:
            self.domains = domains

    @property
    def total(self):
        """Gets the total of this ListDomainsResponse.

        总条数。

        :return: The total of this ListDomainsResponse.
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this ListDomainsResponse.

        总条数。

        :param total: The total of this ListDomainsResponse.
        :type: int
        """
        self._total = total

    @property
    def domains(self):
        """Gets the domains of this ListDomainsResponse.

        域名信息

        :return: The domains of this ListDomainsResponse.
        :rtype: list[Domains]
        """
        return self._domains

    @domains.setter
    def domains(self, domains):
        """Sets the domains of this ListDomainsResponse.

        域名信息

        :param domains: The domains of this ListDomainsResponse.
        :type: list[Domains]
        """
        self._domains = domains

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListDomainsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
